/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
"use strict";

/* exported startup, shutdown, install, uninstall */
/* global Components, AppConstants, Services */

const { interfaces: Ci, utils: Cu, classes: Cc } = Components;

Cu.import("resource://gre/modules/Services.jsm");
Cu.import("resource://gre/modules/AppConstants.jsm");

function hideLoopMenuOption(domWindow) {
  let button = domWindow.document.getElementById("menu_openLoop");
  if (button) {
    button.hidden = true;
  }
}

var WindowListener = {
  // nsIWindowMediatorListener functions.
  onOpenWindow: function(xulWindow) {
    let domWindow = xulWindow.QueryInterface(Ci.nsIInterfaceRequestor)
                             .getInterface(Ci.nsIDOMWindow);
    // Wait for it to finish loading.
    domWindow.addEventListener("load", function listener() {
      domWindow.removeEventListener("load", listener, false);

      // If this is a browser window then setup its UI.
      if (domWindow.document.documentElement.getAttribute("windowtype") === "navigator:browser") {
        hideLoopMenuOption(domWindow);
      }
    });
  }
};

function startup() {
  // Attach to hidden window (for OS X).
  if (AppConstants.platform === "macosx") {
    try {
      hideLoopMenuOption(Services.appShell.hiddenDOMWindow);
    } catch (ex) {
      // Hidden window didn't exist, so wait until startup is done.
      let topic = "browser-delayed-startup-finished";
      Services.obs.addObserver(function observer() {
        Services.obs.removeObserver(observer, topic);
        hideLoopMenuOption(Services.appShell.hiddenDOMWindow);
      }, topic, false);
    }
  }

  // Attach to existing browser windows, for modifying UI.
  let wm = Cc["@mozilla.org/appshell/window-mediator;1"].getService(Ci.nsIWindowMediator);
  let windows = wm.getEnumerator("navigator:browser");
  while (windows.hasMoreElements()) {
    let domWindow = windows.getNext().QueryInterface(Ci.nsIDOMWindow);
    hideLoopMenuOption(domWindow);
  }

  // Wait for any new browser windows to open.
  wm.addListener(WindowListener);

}

function shutdown() {
  let wm = Cc["@mozilla.org/appshell/window-mediator;1"].getService(Ci.nsIWindowMediator);
  wm.removeListener(WindowListener);
}

function install() {
  // For 45 - 48, just installing this new add-on version is enough to disable
  // Loop as it overrides the shipped system add-on.
  // For 44, we need to disable the pref, as Loop was built-in to Firefox (not
  // an add-on).
  if (Services.prefs.getBoolPref("loop.enabled") &&
      Services.vc.compare(Services.appinfo.version, "45.0a1") < 0) {
    Services.prefs.setBoolPref("loop.enabled", false);
  }
}

function uninstall() {}
